@@ -19,6 +19,7 @@ _known_functions_numpy = dict(_in_numpy, **{
     'sign': 'sign',
     'logaddexp': 'logaddexp',
     'logaddexp2': 'logaddexp2',
+    'isnan': 'isnan'
 })
 _known_constants_numpy = {
     'Exp1': 'e',
@@ -215,11 +216,10 @@ class NumPyPrinter(ArrayPrinter, PythonCodePrinter):
         return self._hprint_Pow(expr, rational=rational, sqrt=self._module + '.sqrt')
 
     def _print_Min(self, expr):
-        return '{}(({}), axis=0)'.format(self._module_format(self._module + '.amin'), ','.join(self._print(i) for i in expr.args))
+        return '{}({}.asarray([{}]), axis=0)'.format(self._module_format(self._module + '.amin'), self._module_format(self._module), ','.join(self._print(i) for i in expr.args))
 
     def _print_Max(self, expr):
-        return '{}(({}), axis=0)'.format(self._module_format(self._module + '.amax'), ','.join(self._print(i) for i in expr.args))
-
+        return '{}({}.asarray([{}]), axis=0)'.format(self._module_format(self._module + '.amax'), self._module_format(self._module), ','.join(self._print(i) for i in expr.args))
     def _print_arg(self, expr):
         return "%s(%s)" % (self._module_format(self._module + '.angle'), self._print(expr.args[0]))
 
@@ -259,7 +259,7 @@ class NumPyPrinter(ArrayPrinter, PythonCodePrinter):
         if len(expr.shape) == 2:
             return self._print(expr.tomatrix())
         # Should be possible to extend to more dimensions
-        return CodePrinter._print_not_supported(self, expr)
+        return super()._print_not_supported(self, expr)
 
     _add = "add"
     _einsum = "einsum"
@@ -484,6 +484,7 @@ class JaxPrinter(NumPyPrinter):
 
     def __init__(self, settings=None):
         super().__init__(settings=settings)
+        self.printmethod = '_jaxcode'
 
     # These need specific override to allow for the lack of "jax.numpy.reduce"
     def _print_And(self, expr):
